==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/bean/SubpackagematerialanalysisdetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算材料分析子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackagematerialanalysisdetail")
public class SubpackagematerialanalysisdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="materials_name")
    private java.lang.String materialsName; // 物资名称
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="quantities_base")
    private java.math.BigDecimal quantitiesBase; // 分包基础清单工程量
    @TableField(value="material_waste_rate_base")
    private java.math.BigDecimal materialWasteRateBase; // 合同约定基础用料损耗率
    @TableField(value="material_waste_base")
    private java.math.BigDecimal materialWasteBase; // 基础用料损耗量
    @TableField(value="material_dosage_base")
    private java.math.BigDecimal materialDosageBase; // 基础材料用量
    @TableField(value="quantities_main")
    private java.math.BigDecimal quantitiesMain; // 分包主体清单工程量
    @TableField(value="material_waste_rate_main")
    private java.math.BigDecimal materialWasteRateMain; // 合同约定主体用料损耗率
    @TableField(value="material_waste_main")
    private java.math.BigDecimal materialWasteMain; // 主体用料损耗量
    @TableField(value="material_dosage_main")
    private java.math.BigDecimal materialDosageMain; // 主体材料用量
    @TableField(value="quantities_decorate")
    private java.math.BigDecimal quantitiesDecorate; // 分包装修清单工程量
    @TableField(value="material_waste_rate_decorate")
    private java.math.BigDecimal materialWasteRateDecorate; // 合同约定装修用料损耗率
    @TableField(value="material_waste_decorate")
    private java.math.BigDecimal materialWasteDecorate; // 装修用料损耗量
    @TableField(value="material_dosage_decorate")
    private java.math.BigDecimal materialDosageDecorate; // 装修材料用量
    @TableField(value="subtotal")
    private java.math.BigDecimal subtotal; // 小计
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialsName() {
        return materialsName;
    }

    /**
     * 物资名称
     */
    public void setMaterialsName(java.lang.String materialsName) {
        this.materialsName = materialsName;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 分包基础清单工程量
     */
    public java.math.BigDecimal getQuantitiesBase() {
        return quantitiesBase;
    }

    /**
     * 分包基础清单工程量
     */
    public void setQuantitiesBase(java.math.BigDecimal quantitiesBase) {
        this.quantitiesBase = quantitiesBase;
    }
    /**
     * 合同约定基础用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateBase() {
        return materialWasteRateBase;
    }

    /**
     * 合同约定基础用料损耗率
     */
    public void setMaterialWasteRateBase(java.math.BigDecimal materialWasteRateBase) {
        this.materialWasteRateBase = materialWasteRateBase;
    }
    /**
     * 基础用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteBase() {
        return materialWasteBase;
    }

    /**
     * 基础用料损耗量
     */
    public void setMaterialWasteBase(java.math.BigDecimal materialWasteBase) {
        this.materialWasteBase = materialWasteBase;
    }
    /**
     * 基础材料用量
     */
    public java.math.BigDecimal getMaterialDosageBase() {
        return materialDosageBase;
    }

    /**
     * 基础材料用量
     */
    public void setMaterialDosageBase(java.math.BigDecimal materialDosageBase) {
        this.materialDosageBase = materialDosageBase;
    }
    /**
     * 分包主体清单工程量
     */
    public java.math.BigDecimal getQuantitiesMain() {
        return quantitiesMain;
    }

    /**
     * 分包主体清单工程量
     */
    public void setQuantitiesMain(java.math.BigDecimal quantitiesMain) {
        this.quantitiesMain = quantitiesMain;
    }
    /**
     * 合同约定主体用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateMain() {
        return materialWasteRateMain;
    }

    /**
     * 合同约定主体用料损耗率
     */
    public void setMaterialWasteRateMain(java.math.BigDecimal materialWasteRateMain) {
        this.materialWasteRateMain = materialWasteRateMain;
    }
    /**
     * 主体用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteMain() {
        return materialWasteMain;
    }

    /**
     * 主体用料损耗量
     */
    public void setMaterialWasteMain(java.math.BigDecimal materialWasteMain) {
        this.materialWasteMain = materialWasteMain;
    }
    /**
     * 主体材料用量
     */
    public java.math.BigDecimal getMaterialDosageMain() {
        return materialDosageMain;
    }

    /**
     * 主体材料用量
     */
    public void setMaterialDosageMain(java.math.BigDecimal materialDosageMain) {
        this.materialDosageMain = materialDosageMain;
    }
    /**
     * 分包装修清单工程量
     */
    public java.math.BigDecimal getQuantitiesDecorate() {
        return quantitiesDecorate;
    }

    /**
     * 分包装修清单工程量
     */
    public void setQuantitiesDecorate(java.math.BigDecimal quantitiesDecorate) {
        this.quantitiesDecorate = quantitiesDecorate;
    }
    /**
     * 合同约定装修用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateDecorate() {
        return materialWasteRateDecorate;
    }

    /**
     * 合同约定装修用料损耗率
     */
    public void setMaterialWasteRateDecorate(java.math.BigDecimal materialWasteRateDecorate) {
        this.materialWasteRateDecorate = materialWasteRateDecorate;
    }
    /**
     * 装修用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteDecorate() {
        return materialWasteDecorate;
    }

    /**
     * 装修用料损耗量
     */
    public void setMaterialWasteDecorate(java.math.BigDecimal materialWasteDecorate) {
        this.materialWasteDecorate = materialWasteDecorate;
    }
    /**
     * 装修材料用量
     */
    public java.math.BigDecimal getMaterialDosageDecorate() {
        return materialDosageDecorate;
    }

    /**
     * 装修材料用量
     */
    public void setMaterialDosageDecorate(java.math.BigDecimal materialDosageDecorate) {
        this.materialDosageDecorate = materialDosageDecorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/bedget/bean/SubpackagematerialanalysisdetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算材料分析子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackagematerialanalysisdetail")
public class SubpackagematerialanalysisdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id



    @TableField(value="materials_code")
    private java.lang.String materialsCode; // 物资id
    @TableField(value="materials_name")
    private java.lang.String materialsName; // 物资名称
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="quantities_base")
    private java.math.BigDecimal quantitiesBase; // 分包基础清单工程量
    @TableField(value="material_waste_rate_base")
    private java.math.BigDecimal materialWasteRateBase; // 合同约定基础用料损耗率
    @TableField(value="material_waste_base")
    private java.math.BigDecimal materialWasteBase; // 基础用料损耗量
    @TableField(value="material_dosage_base")
    private java.math.BigDecimal materialDosageBase; // 基础材料用量
    @TableField(value="quantities_main")
    private java.math.BigDecimal quantitiesMain; // 分包主体清单工程量
    @TableField(value="material_waste_rate_main")
    private java.math.BigDecimal materialWasteRateMain; // 合同约定主体用料损耗率
    @TableField(value="material_waste_main")
    private java.math.BigDecimal materialWasteMain; // 主体用料损耗量
    @TableField(value="material_dosage_main")
    private java.math.BigDecimal materialDosageMain; // 主体材料用量
    @TableField(value="quantities_decorate")
    private java.math.BigDecimal quantitiesDecorate; // 分包装修清单工程量
    @TableField(value="material_waste_rate_decorate")
    private java.math.BigDecimal materialWasteRateDecorate; // 合同约定装修用料损耗率
    @TableField(value="material_waste_decorate")
    private java.math.BigDecimal materialWasteDecorate; // 装修用料损耗量
    @TableField(value="material_dosage_decorate")
    private java.math.BigDecimal materialDosageDecorate; // 装修材料用量
    @TableField(value="subtotal")
    private java.math.BigDecimal subtotal; // 小计
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注


    public String getMaterialsCode() {
        return materialsCode;
    }

    public void setMaterialsCode(String materialsCode) {
        this.materialsCode = materialsCode;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialsName() {
        return materialsName;
    }

    /**
     * 物资名称
     */
    public void setMaterialsName(java.lang.String materialsName) {
        this.materialsName = materialsName;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 分包基础清单工程量
     */
    public java.math.BigDecimal getQuantitiesBase() {
        return quantitiesBase;
    }

    /**
     * 分包基础清单工程量
     */
    public void setQuantitiesBase(java.math.BigDecimal quantitiesBase) {
        this.quantitiesBase = quantitiesBase;
    }
    /**
     * 合同约定基础用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateBase() {
        return materialWasteRateBase;
    }

    /**
     * 合同约定基础用料损耗率
     */
    public void setMaterialWasteRateBase(java.math.BigDecimal materialWasteRateBase) {
        this.materialWasteRateBase = materialWasteRateBase;
    }
    /**
     * 基础用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteBase() {
        return materialWasteBase;
    }

    /**
     * 基础用料损耗量
     */
    public void setMaterialWasteBase(java.math.BigDecimal materialWasteBase) {
        this.materialWasteBase = materialWasteBase;
    }
    /**
     * 基础材料用量
     */
    public java.math.BigDecimal getMaterialDosageBase() {
        return materialDosageBase;
    }

    /**
     * 基础材料用量
     */
    public void setMaterialDosageBase(java.math.BigDecimal materialDosageBase) {
        this.materialDosageBase = materialDosageBase;
    }
    /**
     * 分包主体清单工程量
     */
    public java.math.BigDecimal getQuantitiesMain() {
        return quantitiesMain;
    }

    /**
     * 分包主体清单工程量
     */
    public void setQuantitiesMain(java.math.BigDecimal quantitiesMain) {
        this.quantitiesMain = quantitiesMain;
    }
    /**
     * 合同约定主体用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateMain() {
        return materialWasteRateMain;
    }

    /**
     * 合同约定主体用料损耗率
     */
    public void setMaterialWasteRateMain(java.math.BigDecimal materialWasteRateMain) {
        this.materialWasteRateMain = materialWasteRateMain;
    }
    /**
     * 主体用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteMain() {
        return materialWasteMain;
    }

    /**
     * 主体用料损耗量
     */
    public void setMaterialWasteMain(java.math.BigDecimal materialWasteMain) {
        this.materialWasteMain = materialWasteMain;
    }
    /**
     * 主体材料用量
     */
    public java.math.BigDecimal getMaterialDosageMain() {
        return materialDosageMain;
    }

    /**
     * 主体材料用量
     */
    public void setMaterialDosageMain(java.math.BigDecimal materialDosageMain) {
        this.materialDosageMain = materialDosageMain;
    }
    /**
     * 分包装修清单工程量
     */
    public java.math.BigDecimal getQuantitiesDecorate() {
        return quantitiesDecorate;
    }

    /**
     * 分包装修清单工程量
     */
    public void setQuantitiesDecorate(java.math.BigDecimal quantitiesDecorate) {
        this.quantitiesDecorate = quantitiesDecorate;
    }
    /**
     * 合同约定装修用料损耗率
     */
    public java.math.BigDecimal getMaterialWasteRateDecorate() {
        return materialWasteRateDecorate;
    }

    /**
     * 合同约定装修用料损耗率
     */
    public void setMaterialWasteRateDecorate(java.math.BigDecimal materialWasteRateDecorate) {
        this.materialWasteRateDecorate = materialWasteRateDecorate;
    }
    /**
     * 装修用料损耗量
     */
    public java.math.BigDecimal getMaterialWasteDecorate() {
        return materialWasteDecorate;
    }

    /**
     * 装修用料损耗量
     */
    public void setMaterialWasteDecorate(java.math.BigDecimal materialWasteDecorate) {
        this.materialWasteDecorate = materialWasteDecorate;
    }
    /**
     * 装修材料用量
     */
    public java.math.BigDecimal getMaterialDosageDecorate() {
        return materialDosageDecorate;
    }

    /**
     * 装修材料用量
     */
    public void setMaterialDosageDecorate(java.math.BigDecimal materialDosageDecorate) {
        this.materialDosageDecorate = materialDosageDecorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
